@@ -23,6 +23,12 @@ class TermUI:
         print(txt, file=sys.stderr)
     warn = error
 
+
+class NullHandler(logging.Handler):
+    def emit(self, record):
+        pass
+
+
 def expose(func):
     func.api_exposed = True
     return func
@@ -62,14 +68,22 @@ class BroCtl(object):
 
         self.config = config.Configuration(self.brobase, cfgfile, broscriptdir, self.ui, state)
 
-        # clear the log handlers (set by previous calls to logging.*)
+        # Remove all log handlers (set by any previous calls to logging.*)
         logging.getLogger().handlers = []
-        logging.basicConfig(filename=self.config.debuglog,
+
+        if self.config.debug:
+            # Add a log handler that logs to a file.
+            try:
+                logging.basicConfig(filename=self.config.debuglog,
                             format="%(asctime)s [%(module)s] %(message)s",
                             datefmt=self.config.timefmt,
                             level=logging.DEBUG)
-        if not self.config.debug:
-            logging.getLogger().setLevel(100)
+            except IOError as err:
+                raise RuntimeEnvironmentError("%s\nCheck if the user running BroControl has write access to the debug log file." % err)
+        else:
+            # Add a log handler that does nothing.
+            h = NullHandler()
+            logging.getLogger().addHandler(h)
 
         self.executor = execute.Executor(self.config)
         self.plugins = pluginreg.PluginRegistry()
@@ -98,10 +112,20 @@ class BroCtl(object):
     def reload_cfg(self):
         self.config.reload_cfg()
 
-        if not self.config.debug:
-            logging.getLogger().setLevel(100)
+        if self.config.debug:
+            if isinstance(logging.getLogger().handlers[0], NullHandler):
+                # Remove the null handler and configure logging to a file.
+                logging.getLogger().handlers = []
+                logging.basicConfig(filename=self.config.debuglog,
+                            format="%(asctime)s [%(module)s] %(message)s",
+                            datefmt=self.config.timefmt,
+                            level=logging.DEBUG)
+
+            # Re-enable all log levels.
+            logging.disable(logging.NOTSET)
         else:
-            logging.getLogger().setLevel(logging.NOTSET)
+            # Disable logging to all log levels that we use.
+            logging.disable(logging.CRITICAL)
 
         self.executor.finish()
         self.plugins.initPluginOptions()
@@ -120,23 +144,23 @@ class BroCtl(object):
     # then only one node per host is chosen.  If "get_types" is True, then
     # only one node per node type (manager, proxy, etc.) is chosen.
     def node_args(self, args=None, get_hosts=False, get_types=False):
-        if not args:
-            args = "all"
-
         nodes = []
 
-        for arg in args.split():
-            nodelist = self.config.nodes(arg)
-            if not nodelist and arg != "all":
-                raise InvalidNodeError("unknown node '%s'" % arg)
+        if args:
+            for arg in args.split():
+                nodelist = self.config.nodes(arg)
+                if not nodelist:
+                    raise InvalidNodeError("unknown node '%s'" % arg)
 
-            nodes += nodelist
+                nodes += nodelist
 
-        if args != "all":
             # Remove duplicate nodes
             newlist = list(set(nodes))
             if len(newlist) != len(nodes):
                 nodes = newlist
+        else:
+            # Get all nodes.
+            nodes = self.config.nodes()
 
         # Sort the list so that it doesn't depend on initial order of arguments
         nodes.sort(key=node_mod.sortnode)
@@ -176,6 +200,9 @@ class BroCtl(object):
     def node_names(self):
         return [ n.name for n in self.config.nodes() ]
 
+    def node_groups(self):
+        return node_mod.node_groups()
+
     @expose
     @check_config
     def nodes(self):
@@ -421,6 +448,7 @@ class BroCtl(object):
     @check_config
     @lock_required
     def update(self, node_list=None):
+        self.ui.info("warning: 'update' is deprecated and will be removed in a future version.")
         nodes = self.node_args(node_list)
         nodes = self.plugins.cmdPreWithNodes("update", nodes)
         results = self.controller.update(nodes)
@@ -466,10 +494,9 @@ class BroCtl(object):
     @lock_required
     def netstats(self, node_list=None):
         if not node_list:
-            if self.config.nodes("standalone"):
-                node_list = "standalone"
-            else:
-                node_list = "workers"
+            node_list = None
+            if not self.config.standalone:
+                node_list = node_mod.worker_group()
 
         nodes = self.node_args(node_list)
         nodes = self.plugins.cmdPreWithNodes("netstats", nodes)
