@@ -56,7 +56,7 @@ options = [
     Option("CompressExtension", "gz", "string", Option.USER, False,
            "If archived logs will be compressed, the file extension to use on compressed log files. When specifying a file extension, don't include the period character (e.g., specify 'gz' instead of '.gz')."),
 
-    Option("SendMail", "/usr/local/sbin/sendmail", "string", Option.USER, False,
+    Option("SendMail", "/usr/sbin/sendmail", "string", Option.USER, False,
            "Location of the sendmail binary.  Make this string blank to prevent email from being sent. The default value is configuration-dependent and determined automatically by CMake at configure-time. This overrides the Bro script variable Notice::sendmail."),
     Option("MailSubjectPrefix", "[Bro]", "string", Option.USER, False,
            "General Subject prefix for mails. This overrides the Bro script variable Notice::mail_subject_prefix."),
